@@ -27,7 +27,7 @@ from vfscript import vfs
 import pandas as pd
 import matplotlib.pyplot as plt
 from matplotlib.backends.backend_qt5agg import FigureCanvasQTAgg as FigureCanvas
-
+from vfscript.training.preparer import *
 
 # ---------- Gestión de input_params.json ----------
 GUI_ROOT = Path(__file__).resolve().parent
@@ -515,6 +515,25 @@ class TrainingTab(QWidget):
         )
 
 
+    def on_prepare_training_clicked(self):
+        params = load_params()
+        setup_dict = params['CONFIG'][0]['training_setup']
+        out_dir = Path('outputs/training')
+
+        def log_to_gui(msg: str):
+            # si tenés un QTextEdit de log:
+            self.log_output.appendPlainText(str(msg))
+
+        prep = TrainingPreparer.from_setup_dict(setup_dict, out_dir, logger=log_to_gui)
+        try:
+            prep.validate()
+            prep.prepare_workspace()
+            ref_dump = prep.generate_perfect_dump()  # opcional
+            csv = prep.build_dataset_csv([ref_dump])  # reemplazá con tus dumps reales
+            QMessageBox.information(self, "OK", f"Dataset generado:\n{csv}")
+        except Exception as e:
+            QMessageBox.critical(self, "Error en preparación", str(e))
+
 
     # ======== PREVIEW: generación de red y render ========
     def _make_lattice_points(self, lattice: str, a0: float, rx: int, ry: int, rz: int) -> np.ndarray:
